==> praat_6.0.4.orig.tar.gz: praat-6.0.04/sys/oo_undef.h <==
/* oo_undef.h
 *
 * Copyright (C) 1994-2011,2013,2015 Paul Boersma
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#undef oo_SIMPLE
#undef oo_ARRAY
#undef oo_SET
#undef oo_VECTOR
#undef oo_MATRIX

#undef oo_ENUMx
#undef oo_ENUMx_ARRAY
#undef oo_ENUMx_SET
#undef oo_ENUMx_VECTOR

#undef oo_STRINGx
#undef oo_STRINGx_ARRAY
#undef oo_STRINGx_SET
#undef oo_STRINGx_VECTOR

#undef oo_STRUCT
#undef oo_STRUCT_ARRAY
#undef oo_STRUCT_SET
#undef oo_STRUCT_VECTOR_FROM
#undef oo_STRUCT_MATRIX_FROM

#undef oo_OBJECT
#undef oo_AUTO_OBJECT
#undef oo_COLLECTION
#undef oo_AUTO_COLLECTION
#undef oo_FILE
#undef oo_DIR

#undef oo_DEFINE_STRUCT
#undef oo_END_STRUCT

#undef oo_DEFINE_CLASS
#undef oo_END_CLASS

#undef oo_IF
#undef oo_ENDIF

#undef oo_FROM
#undef oo_ENDFROM

#undef oo_DECLARING
#undef oo_DESTROYING
#undef oo_COPYING
#undef oo_COMPARING
#undef oo_VALIDATING_ENCODING
#undef oo_READING
#undef oo_READING_TEXT
#undef oo_READING_BINARY
#undef oo_WRITING
#undef oo_WRITING_TEXT
#undef oo_WRITING_BINARY
#undef oo_DESCRIBING

/* End of file oo_undef.h */

==> praat_6.0.30.orig.tar.gz: praat-6.0.30/sys/oo_undef.h <==
/* oo_undef.h
 *
 * Copyright (C) 1994-2011,2013,2015 Paul Boersma
 *
 * This code is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 *
 * This code is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this work. If not, see <http://www.gnu.org/licenses/>.
 */

#undef oo_SIMPLE
#undef oo_ARRAY
#undef oo_SET
#undef oo_VECTOR
#undef oo_MATRIX

#undef oo_ENUMx
#undef oo_ENUMx_ARRAY
#undef oo_ENUMx_SET
#undef oo_ENUMx_VECTOR

#undef oo_STRINGx
#undef oo_STRINGx_ARRAY
#undef oo_STRINGx_SET
#undef oo_STRINGx_VECTOR

#undef oo_STRUCT
#undef oo_STRUCT_ARRAY
#undef oo_STRUCT_SET
#undef oo_STRUCT_VECTOR_FROM
#undef oo_STRUCT_MATRIX_FROM

#undef oo_AUTO_OBJECT
#undef oo_COLLECTION_OF
#undef oo_AUTO_COLLECTION
#undef oo_FILE
#undef oo_DIR

#undef oo_DEFINE_STRUCT
#undef oo_END_STRUCT

#undef oo_DEFINE_CLASS
#undef oo_END_CLASS

#undef oo_IF
#undef oo_ENDIF

#undef oo_FROM
#undef oo_ENDFROM

#undef oo_DECLARING
#undef oo_DESTROYING
#undef oo_COPYING
#undef oo_COMPARING
#undef oo_VALIDATING_ENCODING
#undef oo_READING
#undef oo_READING_TEXT
#undef oo_READING_BINARY
#undef oo_WRITING
#undef oo_WRITING_TEXT
#undef oo_WRITING_BINARY
#undef oo_DESCRIBING

/* End of file oo_undef.h */
